# 阿里云日志服务 for JSON

## 使用

- `ALIYUN_LOG_ENDPOINT` 日志服务端点，默认根据环境自动配置内外网
- `ALIYUN_LOG_ACCESSID` 阿里云 access id
- `ALIYUN_LOG_ACCESSKEY` 阿里云 access key
- `ALIYUN_LOG_PROJECT` 阿里云日志项目名
- `ALIYUN_LOG_STORE` 阿里云日志存储库名